@@ -1,19 +1,9 @@
 import copy
 import re
 from pynhost.grammars import _homonyms
-try:
-    import constants
-except ImportError:
-    from pynhost import constants
-
-try:
-    import utilities
-except ImportError:
-    from pynhost import utilities
-try:
-    import ruleparser
-except ImportError:
-    from pynhost import ruleparser
+from pynhost import constants
+from pynhost import utilities
+from pynhost import ruleparser
 
 class Tracker:
     def __init__(self, words, rule):
@@ -33,6 +23,8 @@ def words_match_rule(rule, words):
     words = [word.lower() for word in words]
     tracker = Tracker(words, rule)
     results = []
+    if (rule.raw_text == 'hello'):
+        print(rule.pieces, tracker.remaining_words)
     for piece in rule.pieces:
         if isinstance(piece, str):
             if tracker.remaining_words and piece.lower() == tracker.remaining_words[0]:
